@@ -79,14 +79,7 @@ def LATTE_DV(tic, indir, syspath, transit_list, sectors_all, target_ra, target_d
 	
 
 	# TOI -----
-	TOI_planets = pd.read_csv('{}/data/TOI_list.txt'.format(indir), comment = "#")
-	
-	TOIpl = TOI_planets.loc[TOI_planets['TIC'] == float(tic)]
-		
-	if len(TOIpl) == 0:
-		TOI = ' -  '
-	else:
-		TOI = (float(TOIpl["Full TOI ID"]))
+	TOI = ' -  '
 	
 	# ------ PARAMS ------
 	ra = float(target_ra)
