@@ -6,7 +6,6 @@ import pandas
 import wotan
 import matplotlib.pyplot as plt
 import foldedleastsquares as tls
-from foldedleastsquares.template_generator.default_transit_template_generator import DefaultTransitTemplateGenerator
 import numpy as np
 import os
 import sys
@@ -150,12 +149,32 @@ class Sherlock:
         self.use_ois = True
         self.ois = self.ois[self.ois["Disposition"].notnull()]
         self.ois = self.ois[self.ois["Period (days)"].notnull()]
+        self.ois = self.ois[self.ois["Period (days)"] > 0]
         self.ois = self.ois[self.ois["Depth (ppm)"].notnull()]
-        self.ois = self.ois[(self.ois["Disposition"] == "KP") | (self.ois["Disposition"] == "CP") | (self.ois["Disposition"] == "PC")]
+        self.ois = self.ois[
+            (self.ois["Disposition"] == "KP") | (self.ois["Disposition"] == "CP") | (self.ois["Disposition"] == "PC")]
         self.ois = self.ois[self.ois.duplicated(subset=['Object Id'], keep=False)]
         self.ois.sort_values(by=['Object Id', 'OI'])
         return self
 
+    def filter_high_snr_long_period_ois(self):
+        """
+        Filters the in-memory OIs given some basic filters associated to big and long-period targets. This method is added
+        as an example
+        @return: the Sherlock object itself
+        @rtype: Sherlock
+        """
+        self.use_ois = True
+        self.ois = self.ois[self.ois["Disposition"].notnull()]
+        self.ois = self.ois[self.ois["Period (days)"].notnull()]
+        self.ois = self.ois[self.ois["Period (days)"] > 20]
+        self.ois = self.ois[self.ois["Depth (ppm)"].notnull()]
+        self.ois = self.ois[self.ois["Depth (ppm)"] > 7500]
+        self.ois = self.ois[
+            (self.ois["Disposition"] == "KP") | (self.ois["Disposition"] == "CP") | (self.ois["Disposition"] == "PC")]
+        self.ois.sort_values(by=['Object Id', 'OI'])
+        return self
+
     def filter_ois(self, function):
         """
         Applies a function accepting the Sherlock objects of interests dataframe and stores the result into the
@@ -208,7 +227,7 @@ class Sherlock:
             time = lc_build.lc.time.value
             flux = lc_build.lc.flux.value
             flux_err = lc_build.lc.flux_err.value
-            period_grid, sherlock_target.oversampling = LcbuilderHelper.calculate_period_grid(time, sherlock_target.period_min,
+            period_grid, oversampling = LcbuilderHelper.calculate_period_grid(time, sherlock_target.period_min,
                                                                 sherlock_target.period_max,
                                                                 sherlock_target.oversampling,
                                                                 lc_build.star_info, lc_build.transits_min_count)
@@ -672,7 +691,6 @@ class Sherlock:
     def __adjust_transit(self, sherlock_target, time, lc, star_info, transits_min_count, run_results, report, cadence,
                          period_grid, detrend_source_period):
         oversampling = sherlock_target.oversampling
-            #TODO calculate pesimistic oversampling comparing length of curve (
         model = tls.transitleastsquares(time, lc)
         power_args = {"transit_template": sherlock_target.fit_method, "period_min": sherlock_target.period_min,
                       "period_max": sherlock_target.period_max, "n_transits_min": transits_min_count,
