@@ -76,7 +76,7 @@ def add_gaia_figure_elements(tpf, magnitude_limit=18,targ_mag=10.):
     result = result[result.Gmag < magnitude_limit]
     if len(result) == 0:
         raise no_targets_found_message
-    year = ((tpf.astropy_time[0].jd - 2457206.375) * u.day).to(u.year)
+    year = ((tpf.time[0].jd - 2457206.375) * u.day).to(u.year)
     pmra = ((np.nan_to_num(np.asarray(result.pmRA)) * u.milliarcsecond/u.year) * year).to(u.degree).value
     pmdec = ((np.nan_to_num(np.asarray(result.pmDE)) * u.milliarcsecond/u.year) * year).to(u.degree).value
     result.RA_ICRS += pmra
@@ -246,7 +246,7 @@ if __name__ == "__main__":
         	print('Working on TIC'+tic+' (ra = '+str(ra)+', '+'dec = '+str(dec)+') ...')
 
         if args.gid != None:
-        	gaia_id, mag = args.gid, np.float(args.gmag)
+        	gaia_id, mag = args.gid, float(args.gmag)
         else:
             if args.COORD  is not False:
         	       gaia_id, mag = get_gaia_data(ra, dec)
@@ -300,9 +300,10 @@ if __name__ == "__main__":
         mean_tpf = np.mean(tpf.flux,axis=0)
         nx,ny = np.shape(mean_tpf)
         norm = ImageNormalize(stretch=stretching.LogStretch())
-        division = np.int(np.log10(np.nanmax(np.nanmean(tpf.flux,axis=0))))
-        splot = plt.imshow(np.nanmean(tpf.flux,axis=0)/10**division,norm=norm, \
-        				extent=[tpf.column,tpf.column+ny,tpf.row,tpf.row+nx],origin='bottom', zorder=0)
+        division = int(np.log10(np.nanmax(np.nanmean(tpf.flux * u.s/u.electron,axis=0))))
+        image = np.nanmean(tpf.flux,axis=0)/10**division
+        splot = plt.imshow(image,norm=norm, \
+        				extent=[tpf.column,tpf.column+ny,tpf.row,tpf.row+nx],origin='lower', zorder=0)
 
         # Pipeline aperture
         if pipeline == "True":                                           #
@@ -326,7 +327,7 @@ if __name__ == "__main__":
         										   1, 1, color=maskcolor, fill=False,alpha=1,lw=2))
 
         # Gaia sources
-        r, res = add_gaia_figure_elements(tpf,magnitude_limit=mag+np.float(args.maglim),targ_mag=mag)
+        r, res = add_gaia_figure_elements(tpf,magnitude_limit=mag+float(args.maglim),targ_mag=mag)
         x,y,gaiamags = r
         x, y, gaiamags=np.array(x)+0.5, np.array(y)+0.5, np.array(gaiamags)
         size = 128.0 / 2**((gaiamags-mag))
@@ -338,14 +339,14 @@ if __name__ == "__main__":
 
         # Legend
         add = 0
-        if np.int(args.maglim) % 2 != 0:
+        if int(args.maglim) % 2 != 0:
             add = 1
-        maxmag = np.int(args.maglim) + add
-        legend_mags = np.linspace(-2,maxmag,np.int((maxmag+2)/2+1))
+        maxmag = int(args.maglim) + add
+        legend_mags = np.linspace(-2,maxmag,int((maxmag+2)/2+1))
         fake_sizes = mag + legend_mags #np.array([mag-2,mag,mag+2,mag+5, mag+8])
         for f in fake_sizes:
             size = 128.0 / 2**((f-mag))
-            plt.scatter(0,0,s=size,c='red',alpha=0.6, edgecolor=None,zorder = 10,label = r'$\Delta m=$ '+str(np.int(f-mag)))
+            plt.scatter(0,0,s=size,c='red',alpha=0.6, edgecolor=None,zorder = 10,label = r'$\Delta m=$ '+str(int(f-mag)))
 
         ax1.legend(fancybox=True, framealpha=0.7, loc=args.legend)
 
@@ -378,8 +379,12 @@ if __name__ == "__main__":
         pos2 = [pos1.x0 - 0.05, pos1.y0 ,  pos1.width, pos1.height]
         cbax.set_position(pos2) # set a new position
 
-        cb = Colorbar(ax = cbax, mappable = splot, orientation = 'vertical', ticklocation = 'right')
+        cbar_ticks = np.linspace(np.min(image), np.max(image), 8, endpoint=True)
+
+        cb = Colorbar(ax = cbax, mappable = splot, orientation = 'vertical',
+                      ticklocation = 'right')
         plt.xticks(fontsize=14)
+        #cbax.set_yticklabels(["{:4.2f}".format(i) for i in cbar_ticks])
         exponent = r'$\times 10^'+str(division)+'$'
         cb.set_label(r'Flux '+exponent+r' (e$^-$)', labelpad=10, fontsize=16)
 
