@@ -74,7 +74,9 @@ class TtvFitter:
             ttvs_params = f.readlines()
         ttvs_error_str = str(self.ttvs_error)
         ttvs_error_str = ",uniform -" + ttvs_error_str + " " + ttvs_error_str + ","
+        ttvs_initial_str = ",0.0,1,uniform"
         ttvs_params = [re.sub(r",uniform -?\d+(\.\d+)? -?\d+(\.\d+)?,", ttvs_error_str, ttvs_param) for ttvs_param in ttvs_params]
+        ttvs_params = [re.sub(r",-?\d+(\.\d+)?,1,uniform", ttvs_initial_str, ttvs_param) for ttvs_param in ttvs_params]
         with open(self.ttvs_dir + "/params.csv", "a") as params_file:
             params_file.write("\n" + "".join(ttvs_params))
 
@@ -86,7 +88,7 @@ if __name__ == '__main__':
     ap.add_argument('--cpus', type=int, default=4, help="The number of CPU cores to be used.", required=False)
     ap.add_argument('--only_initial', dest='only_initial', action='store_true',
                     help="Whether to only run an initial guess of the ttvs")
-    ap.add_argument('--ttvs_error', type=float, default=0.2, required=False,
+    ap.add_argument('--ttvs_error', type=float, default=0.07, required=False,
                     help="Error window for each single transit fit")
     args = ap.parse_args()
     object_dir = os.getcwd() if args.object_dir is None else args.object_dir
